#
# spec file for package perl-Test-Synopsis
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Test-Synopsis
Name:           perl-Test-Synopsis
Version:        0.17
Release:        bp155.1.4
Summary:        Test your SYNOPSIS code
License:        Artistic-1.0 OR GPL-1.0-or-later
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/Z/ZO/ZOFFIX/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Pod::Simple) >= 3.09
BuildRequires:  perl(Test::Builder) >= 0.34
BuildRequires:  perl(parent)
Requires:       perl(Pod::Simple) >= 3.09
Requires:       perl(parent)
%{perl_requires}

%description
Test::Synopsis is an (author) test module to find .pm or .pod files under
your _lib_ directory and then make sure the example snippet code in your
_SYNOPSIS_ section passes the perl compile check.

Note that this module only checks the perl syntax (by wrapping the code
with 'sub') and doesn't actually run the code, *UNLESS* that code is a
'BEGIN {}' block or a 'use' statement.

Suppose you have the following POD in your module.

  =head1 NAME

  Awesome::Template - My awesome template

  =head1 SYNOPSIS

    use Awesome::Template;

    my $template = Awesome::Template->new;
    $tempalte->render("template.at");

  =head1 DESCRIPTION

An user of your module would try copy-paste this synopsis code and find
that this code doesn't compile because there's a typo in your variable name
_$tempalte_. Test::Synopsis will catch that error before you ship it.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README README.md
%license LICENSE

%changelog
* Sat Dec 11 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.17
  see /usr/share/doc/packages/perl-Test-Synopsis/Changes
  0.17  2021-12-08
  - Mention related module in docs (#22)
* Sat May 25 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.16
  see /usr/share/doc/packages/perl-Test-Synopsis/Changes
  0.16  2019-05-24
  - Fix test failures when version 0.23 of
    Test::Spelling is in use (by ppisar, #21)
* Tue Mar  8 2016 coolo@suse.com
- updated to 0.15
  see /usr/share/doc/packages/perl-Test-Synopsis/Changes
  0.15  2016-03-02
  - Specify Pod::Simple version to prereq, as needed
    feature missing from older versions (by autarch)
* Fri Feb 19 2016 coolo@suse.com
- updated to 0.14
  see /usr/share/doc/packages/perl-Test-Synopsis/Changes
  0.14  2016-02-16
  - Complete rewrite by dolmen
    [BREAKING CHANGES]
  - The undocumented PRIVATE subroutine extract_synopsis
    has been renamed. Any code using it will break
* Wed Jan  6 2016 coolo@suse.com
- updated to 0.13
  see /usr/share/doc/packages/perl-Test-Synopsis/Changes
  0.13  2016-01-04
  - Fix #12 conflict with multiple chunks (by turnstep)
* Sat Jan  2 2016 coolo@suse.com
- updated to 0.12
  see /usr/share/doc/packages/perl-Test-Synopsis/Changes
  0.12  2015-12-27
  - Add META.json (monsieurp)
* Mon Apr 13 2015 coolo@suse.com
- updated to 0.11
  see /usr/share/doc/packages/perl-Test-Synopsis/Changes
  0.11  2014-10-04
    [Changes by ZOFFIX]
  - Added #10 to CAVEATS (redefined warnings)
  - Fixed #11 (failing tests on newer perls)
* Sun Feb  9 2014 coolo@suse.com
- updated to 0.10
    [Changes by ZOFFIX]
  - Reverted the change of renaming extract_synopsis() to
    _extract_synopsis(), as it appears some distros have used
    undocumented extract_synopsis() in their user tests, and
    the change is causing their distros to fail
  - Added contributors into META file through dzil plugin
  - Fixed prereqs to allow earlier versions of Test-Simple (Issue #9)
  - Removed POD errors from test .pm's to increase Kwalitee
  - Implemented proper handling of __DATA__ tokens
  - Removed unwanted warnings issued during tests
  - Upped required Test-Simple distro version (Fixes Issue #9)
  - Minor pod fixes
  - Converted to dzil for automation of everything and
    auto-generation of all the author/release tests and extra files
  - Fixed RT#84863 (should ignore descriptions, and
    other text that is not code)
    https://rt.cpan.org/Ticket/Display.html?id=84863
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Fri Jan 21 2011 coolo@novell.com
- initial package 0.06
  * created by cpanspec 1.78.03
